# Chapicha

A semi-automated image editing tool

## Installation 

Install chapicha from source

```bash 
  git clone https://github.com/julius383/chapicha
  cd chapicha
  poetry install
```
    
## Usage/Examples

```
Usage: main.py [OPTIONS] COMMAND [ARGS]...

Options:
  --verbose TEXT
  --help          Show this message and exit.

Commands:
  crop   Crop images to given dimensions
  ocr    Try and recognize text present in an image
  scale  Scale down an image by a given factor

```

  
## License

[MIT](https://choosealicense.com/licenses/mit/)

  
